==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/DataSourceAggregatedResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescription } from "./DataSourceAggregatedResultDescription";
/**
 * @hidden
 */
export let DataSourceAggregatedResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceAggregatedResultDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceAggregatedResultDescriptionMetadata.a == null) {
                DataSourceAggregatedResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceAggregatedResultDescriptionMetadata.c(DataSourceAggregatedResultDescriptionMetadata.a);
            }
            if (a.k(DataSourceAggregatedResultDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataSourceAggregatedResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("TransactionType", "ExportedType:string:TransactionType");
            a.item("TransactionType@names", "Add;Update;Delete");
            a.item("Keys", "Array:string");
            a.item("ValuesRef", "(w:Values,wf:Values)DataRef:object");
        }
        static d(a) {
            DataSourceAggregatedResultDescriptionMetadata.b(a);
            a.ad("DataSourceAggregatedResult", () => new DataSourceAggregatedResultDescription());
            a.ac("DataSourceAggregatedResult", DataSourceAggregatedResultDescriptionMetadata.a);
        }
    }
    DataSourceAggregatedResultDescriptionMetadata.$t = markType(DataSourceAggregatedResultDescriptionMetadata, 'DataSourceAggregatedResultDescriptionMetadata');
    DataSourceAggregatedResultDescriptionMetadata.a = null;
    return DataSourceAggregatedResultDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/DataSourceAggregatedResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescription } from "./DataSourceAggregatedResultDescription";
/**
 * @hidden
 */
export let DataSourceAggregatedResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceAggregatedResultDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceAggregatedResultDescriptionMetadata.a == null) {
                DataSourceAggregatedResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceAggregatedResultDescriptionMetadata.c(DataSourceAggregatedResultDescriptionMetadata.a);
            }
            if (a.k(DataSourceAggregatedResultDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataSourceAggregatedResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("TransactionType", "ExportedType:string:TransactionType");
            a.item("TransactionType@names", "Add;Update;Delete");
            a.item("Keys", "Array:string");
            a.item("ValuesRef", "(w:Values,wf:Values)DataRef:object");
        }
        static d(a) {
            DataSourceAggregatedResultDescriptionMetadata.b(a);
            a.ae("DataSourceAggregatedResult", () => new DataSourceAggregatedResultDescription());
            a.ad("DataSourceAggregatedResult", DataSourceAggregatedResultDescriptionMetadata.a);
        }
    }
    DataSourceAggregatedResultDescriptionMetadata.$t = markType(DataSourceAggregatedResultDescriptionMetadata, 'DataSourceAggregatedResultDescriptionMetadata');
    DataSourceAggregatedResultDescriptionMetadata.a = null;
    return DataSourceAggregatedResultDescriptionMetadata;
})();
